# Third-party includes

## JSON library `nlohmann/json`
Place `nlohmann/json` headers in `nlohmann` folder.
Current version: 3.11.2 (bc889afb4c5bf1c0d8ee29ef35eaaf4c8bef8a5d)
SHA-256: e5c7a9f49a16814be27e4ed0ee900ecd0092bfb7dbfca65b5a421b774dccaaed (include.zip)

## Format library `fmtlib/fmt`
Place `fmtlib/fmt` headers in `fmt` folder.  
Current version: 9.1.0 (a33701196adfad74917046096bf5a2aa0ab0bb50)
SHA-256: cceb4cb9366e18a5742128cb3524ce5f50e88b476f1e54737a47ffdf4df4c996 (fmt-9.1.0.zip)
